TSSV: Targeted characterisation of short structural variation
=============================================================

.. image:: https://img.shields.io/github/last-commit/jfjlaros/tssv.svg
   :target: https://github.com/jfjlaros/tssv/graphs/commit-activity
.. image:: https://travis-ci.org/jfjlaros/tssv.svg?branch=master
   :target: https://travis-ci.org/jfjlaros/tssv
.. image:: https://readthedocs.org/projects/tssv/badge/?version=latest
   :target: https://tssv.readthedocs.io/en/latest
.. image:: https://img.shields.io/github/release-date/jfjlaros/tssv.svg
   :target: https://github.com/jfjlaros/tssv/releases
.. image:: https://img.shields.io/github/release/jfjlaros/tssv.svg
   :target: https://github.com/jfjlaros/tssv/releases
.. image:: https://img.shields.io/pypi/v/tssv.svg
   :target: https://pypi.org/project/tssv/
.. image:: https://img.shields.io/github/languages/code-size/jfjlaros/tssv.svg
   :target: https://github.com/jfjlaros/tssv
.. image:: https://img.shields.io/github/languages/count/jfjlaros/tssv.svg
   :target: https://github.com/jfjlaros/tssv
.. image:: https://img.shields.io/github/languages/top/jfjlaros/tssv.svg
   :target: https://github.com/jfjlaros/tssv
.. image:: https://img.shields.io/github/license/jfjlaros/tssv.svg
   :target: https://raw.githubusercontent.com/jfjlaros/tssv/master/LICENSE.md

----

TSSV is a program that does targeted characterisation of short structural
variation. It can be used for STR analysis, or any other type of targeted
analysis. It characterises any variation between a set of user-defined markers.

TSSV is platform-independent. It has been tested on Linux, macOS, and Windows.

Please see ReadTheDocs_ for the latest documentation.


.. _ReadTheDocs: https://tssv.readthedocs.io/en/latest/index.html
